@@ -29,7 +29,6 @@ from raiden_contracts.utils.proofs import (
     hash_balance_data,
     sign_balance_proof,
     sign_balance_proof_message,
-    sign_cooperative_settle_message,
     sign_withdraw_message,
 )
 from raiden_contracts.utils.type_aliases import (
@@ -189,6 +188,58 @@ def withdraw_channel(token_network: Contract, create_withdraw_signatures: Callab
     return get
 
 
+@pytest.fixture()
+def cooperative_settle_channel(
+    token_network: Contract, create_withdraw_signatures: Callable
+) -> Callable:
+    def get(
+        channel_identifier: int,
+        participant: HexAddress,
+        partner: HexAddress,
+        withdraw_amount_participant: int,
+        withdraw_amount_partner: int,
+        expiration_block: int,
+        delegate: Optional[HexAddress] = None,
+    ) -> HexBytes:
+        delegate = delegate or participant
+        channel_identifier = token_network.functions.getChannelIdentifier(
+            participant, partner
+        ).call()
+
+        (signature_A1, signature_B1) = create_withdraw_signatures(
+            [participant, partner],
+            channel_identifier,
+            participant,
+            withdraw_amount_participant,
+            expiration_block,
+        )
+        (signature_A2, signature_B2) = create_withdraw_signatures(
+            [participant, partner],
+            channel_identifier,
+            partner,
+            withdraw_amount_partner,
+            expiration_block,
+        )
+
+        txn_hash = call_and_transact(
+            token_network.functions.cooperativeSettle(
+                channel_identifier,
+                (
+                    participant,
+                    withdraw_amount_participant,
+                    expiration_block,
+                    signature_A1,
+                    signature_B1,
+                ),
+                (partner, withdraw_amount_partner, expiration_block, signature_B2, signature_A2),
+            ),
+            {"from": delegate},
+        )
+        return txn_hash
+
+    return get
+
+
 @pytest.fixture()
 def close_and_update_channel(
     token_network: Contract,
@@ -766,41 +817,6 @@ def create_close_signature_for_no_balance_proof(
     return get
 
 
-@pytest.fixture()
-def create_cooperative_settle_signatures(
-    token_network: Contract, get_private_key: Callable
-) -> Callable:
-    def get(
-        participants_to_sign: HexAddress,
-        channel_identifier: ChannelID,
-        participant1_address: HexAddress,
-        participant1_balance: TokenAmount,
-        participant2_address: HexAddress,
-        participant2_balance: TokenAmount,
-        v: int = 27,
-        other_token_network: Optional[Contract] = None,
-    ) -> List[bytes]:
-        _token_network = other_token_network or token_network
-        signatures = []
-        for participant in participants_to_sign:
-            private_key = get_private_key(participant)
-            signature = sign_cooperative_settle_message(
-                private_key,
-                _token_network.address,
-                _token_network.functions.chain_id().call(),
-                channel_identifier,
-                participant1_address,
-                participant1_balance,
-                participant2_address,
-                participant2_balance,
-                v,
-            )
-            signatures.append(signature)
-        return signatures
-
-    return get
-
-
 @pytest.fixture()
 def create_withdraw_signatures(token_network: Contract, get_private_key: Callable) -> Callable:
     def get(
