@@ -6,16 +6,18 @@ from web3.contract import Contract
 from web3.exceptions import ValidationError
 
 from raiden_contracts.constants import EMPTY_ADDRESS, ChannelEvent
-from raiden_contracts.tests.utils import call_and_transact
-from raiden_contracts.utils.events import check_channel_settled
+from raiden_contracts.tests.utils import EMPTY_LOCKSROOT, call_and_transact
+from raiden_contracts.utils.events import check_channel_settled, check_withdraw_2
+from raiden_contracts.utils.type_aliases import BlockExpiration
+
+EXPIRATION = BlockExpiration(100)
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_call(
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
     deposit_A = 20
@@ -25,76 +27,99 @@ def test_cooperative_settle_channel_call(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
     )
 
+    # negative balances
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, -1, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, -1, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         )
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, -1, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, -1, EXPIRATION, signature_B2, signature_A2),
+        )
+    # wrong participant addresses
+    with pytest.raises(ValidationError):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (0x0, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         )
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, 0x0, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (0x0, balance_B, EXPIRATION, signature_B2, signature_A2),
+        )
+    # invalid signatures
+    with pytest.raises(ValidationError):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (A, balance_A, EXPIRATION, 0x0, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         )
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, 0x0, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, 0x0),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         )
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, 0x0, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, 0x0, signature_A2),
         )
     with pytest.raises(ValidationError):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, 0x0
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, 0x0),
         )
-
-    with pytest.raises(TransactionFailed):
+    # empty addresses
+    with pytest.raises(TransactionFailed, match="TN: participant address zero"):
         call_and_transact(
             token_network.functions.cooperativeSettle(
                 channel_identifier,
-                EMPTY_ADDRESS,
-                balance_A,
-                B,
-                balance_B,
-                signature_A,
-                signature_B,
+                (EMPTY_ADDRESS, balance_A, EXPIRATION, signature_A1, signature_B1),
+                (B, balance_B, EXPIRATION, signature_B2, signature_A2),
             ),
             {"from": C},
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: partner address zero"):
         call_and_transact(
             token_network.functions.cooperativeSettle(
                 channel_identifier,
-                A,
-                balance_A,
-                EMPTY_ADDRESS,
-                balance_B,
-                signature_A,
-                signature_B,
+                (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+                (EMPTY_ADDRESS, balance_B, EXPIRATION, signature_B2, signature_A2),
             ),
             {"from": C},
         )
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_signatures(
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
     deposit_A = 20
@@ -104,38 +129,61 @@ def test_cooperative_settle_channel_signatures(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B, signature_C) = create_cooperative_settle_signatures(
-        [A, B, C], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1, signature_B1, signature_C1) = create_withdraw_signatures(
+        [A, B, C], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2, signature_C2) = create_withdraw_signatures(
+        [A, B, C], channel_identifier, B, balance_B, EXPIRATION
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_C, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_C1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ).call({"from": C})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_C
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_C1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ).call({"from": C})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_B, B, balance_A, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_C2, signature_A2),
+        ).call({"from": C})
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_C2),
+        ).call({"from": C})
+
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (A, balance_B, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_A, EXPIRATION, signature_B2, signature_A2),
         ).call({"from": C})
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_0(
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
     cooperative_settle_state_tests: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
@@ -146,8 +194,11 @@ def test_cooperative_settle_channel_0(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B, _) = create_cooperative_settle_signatures(
-        [A, B, C], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
     )
 
     pre_account_balance_A = custom_token.functions.balanceOf(A).call()
@@ -156,7 +207,9 @@ def test_cooperative_settle_channel_0(
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
@@ -173,13 +226,12 @@ def test_cooperative_settle_channel_0(
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_00(
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
     cooperative_settle_state_tests: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
@@ -190,8 +242,11 @@ def test_cooperative_settle_channel_00(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B, _) = create_cooperative_settle_signatures(
-        [A, B, C], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
     )
 
     pre_account_balance_A = custom_token.functions.balanceOf(A).call()
@@ -200,7 +255,9 @@ def test_cooperative_settle_channel_00(
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
@@ -217,13 +274,12 @@ def test_cooperative_settle_channel_00(
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_state(
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
     cooperative_settle_state_tests: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
@@ -235,8 +291,11 @@ def test_cooperative_settle_channel_state(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
     )
 
     pre_account_balance_A = custom_token.functions.balanceOf(A).call()
@@ -245,7 +304,9 @@ def test_cooperative_settle_channel_state(
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
@@ -262,14 +323,13 @@ def test_cooperative_settle_channel_state(
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_state_withdraw(
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     withdraw_channel: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
     cooperative_settle_state_tests: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
@@ -282,11 +342,16 @@ def test_cooperative_settle_channel_state_withdraw(
     assert deposit_A + deposit_B == withdraw_A + withdraw_B + balance_A + balance_B
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
-    withdraw_channel(channel_identifier, A, withdraw_A, B)
-    withdraw_channel(channel_identifier, B, withdraw_B, A)
+    withdraw_channel(channel_identifier, A, withdraw_A, EXPIRATION, B)
+    withdraw_channel(channel_identifier, B, withdraw_B, EXPIRATION, A)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A, B, balance_B
+    # We need to add the already withdrawn amount to the balance as `withdraw_amount`
+    # is a monotonic value
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A + withdraw_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B + withdraw_B, EXPIRATION
     )
 
     pre_account_balance_A = custom_token.functions.balanceOf(A).call()
@@ -295,7 +360,9 @@ def test_cooperative_settle_channel_state_withdraw(
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A + withdraw_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B + withdraw_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
@@ -312,13 +379,41 @@ def test_cooperative_settle_channel_state_withdraw(
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
+def test_cooperative_settle_channel_smaller_total_amount(
+    token_network: Contract,
+    create_channel_and_deposit: Callable,
+    get_accounts: Callable,
+    create_withdraw_signatures: Callable,
+) -> None:
+    (A, B, C) = get_accounts(3)
+    deposit_A = 20
+    deposit_B = 10
+    balance_A = 15 - 1
+    balance_B = 15
+
+    channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
+
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
+    )
+
+    with pytest.raises(TransactionFailed, match="TN/coopSettle: incomplete amount"):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
+        ).call({"from": C})
+
+
 def test_cooperative_settle_channel_bigger_withdraw(
     token_network: Contract,
     create_channel_and_deposit: Callable,
     withdraw_channel: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
     deposit_A = 20
@@ -330,25 +425,31 @@ def test_cooperative_settle_channel_bigger_withdraw(
     assert deposit_A + deposit_B < withdraw_A + withdraw_B + balance_A + balance_B
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
-    withdraw_channel(channel_identifier, A, withdraw_A, B)
-    withdraw_channel(channel_identifier, B, withdraw_B, A)
+    withdraw_channel(channel_identifier, A, withdraw_A, EXPIRATION, B)
+    withdraw_channel(channel_identifier, B, withdraw_B, EXPIRATION, A)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A, B, balance_B
+    # We need to add the already withdrawn amount to the balance as `withdraw_amount`
+    # is a monotonic value
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A + withdraw_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B + withdraw_B, EXPIRATION
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/coopSettle: incomplete amount"):
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A + withdraw_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B + withdraw_B, EXPIRATION, signature_B2, signature_A2),
         ).call({"from": C})
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_wrong_balances(
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
 ) -> None:
     (A, B, C) = get_accounts(3)
     deposit_A = 20
@@ -363,52 +464,56 @@ def test_cooperative_settle_channel_wrong_balances(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A, B, balance_B
+    (signature_A1_fail1, signature_B1_fail1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A_fail1, EXPIRATION
     )
-    (signature_A_fail1, signature_B_fail1) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A_fail1, B, balance_B_fail1
-    )
-    (signature_A_fail2, signature_B_fail2) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, A, balance_A_fail2, B, balance_B_fail2
+    (signature_A2_fail1, signature_B2_fail1) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B_fail1, EXPIRATION
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/coopSettle: incomplete amount"):
         token_network.functions.cooperativeSettle(
             channel_identifier,
-            A,
-            balance_A_fail1,
-            B,
-            balance_B_fail1,
-            signature_A_fail1,
-            signature_B_fail1,
-        ).call({"from": C})
-    with pytest.raises(TransactionFailed):
-        token_network.functions.cooperativeSettle(
-            channel_identifier,
-            A,
-            balance_A_fail2,
-            B,
-            balance_B_fail2,
-            signature_A_fail2,
-            signature_B_fail2,
+            (A, balance_A_fail1, EXPIRATION, signature_A1_fail1, signature_B1_fail1),
+            (B, balance_B_fail1, EXPIRATION, signature_B2_fail1, signature_A2_fail1),
         ).call({"from": C})
 
+    (signature_A1_fail2, signature_B1_fail2) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A_fail2, EXPIRATION
+    )
+    (signature_A2_fail2, signature_B2_fail2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B_fail2, EXPIRATION
+    )
+
+    with pytest.raises(TransactionFailed, match="TN/coopSettle: incomplete amount"):
+        token_network.functions.cooperativeSettle(
+            channel_identifier,
+            (A, balance_A_fail1, EXPIRATION, signature_A1_fail2, signature_B1_fail2),
+            (B, balance_B_fail1, EXPIRATION, signature_B2_fail2, signature_A2_fail2),
+        ).call({"from": C})
+
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
+    )
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, A, balance_A, B, balance_B, signature_A, signature_B
+            channel_identifier,
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
         ),
         {"from": C},
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_close_replay_reopened_channel(
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
 ) -> None:
     (A, B) = get_accounts(2)
     deposit_A = 15
@@ -420,13 +525,18 @@ def test_cooperative_close_replay_reopened_channel(
     channel_deposit(channel_identifier1, A, deposit_A, B)
     channel_deposit(channel_identifier1, B, deposit_B, A)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier1, B, balance_B, A, balance_A
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier1, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier1, B, balance_B, EXPIRATION
     )
 
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier1, B, balance_B, A, balance_A, signature_B, signature_A
+            channel_identifier1,
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
         ),
         {"from": B},
     )
@@ -437,30 +547,36 @@ def test_cooperative_close_replay_reopened_channel(
     channel_deposit(channel_identifier2, B, deposit_B, A)
 
     assert channel_identifier1 != channel_identifier2
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.cooperativeSettle(
-            channel_identifier2, B, balance_B, A, balance_A, signature_B, signature_A
+            channel_identifier2,
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
         ).call({"from": B})
 
     # Signed message with the correct channel identifier must work
-    (signature_A2, signature_B2) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier2, B, balance_B, A, balance_A
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier2, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier2, B, balance_B, EXPIRATION
     )
     call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier2, B, balance_B, A, balance_A, signature_B2, signature_A2
+            channel_identifier2,
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
         ),
         {"from": B},
     )
 
 
-@pytest.mark.skip(reason="Delayed until another milestone")
 def test_cooperative_settle_channel_event(
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
-    create_cooperative_settle_signatures: Callable,
+    create_withdraw_signatures: Callable,
     event_handler: Callable,
 ) -> None:
     ev_handler = event_handler(token_network)
@@ -468,23 +584,41 @@ def test_cooperative_settle_channel_event(
     deposit_A = 10
     balance_A = 2
     balance_B = 8
+
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
 
-    (signature_A, signature_B) = create_cooperative_settle_signatures(
-        [A, B], channel_identifier, B, balance_B, A, balance_A
+    (signature_A1, signature_B1) = create_withdraw_signatures(
+        [A, B], channel_identifier, A, balance_A, EXPIRATION
+    )
+    (signature_A2, signature_B2) = create_withdraw_signatures(
+        [A, B], channel_identifier, B, balance_B, EXPIRATION
     )
 
     txn_hash = call_and_transact(
         token_network.functions.cooperativeSettle(
-            channel_identifier, B, balance_B, A, balance_A, signature_B, signature_A
+            channel_identifier,
+            (B, balance_B, EXPIRATION, signature_B2, signature_A2),
+            (A, balance_A, EXPIRATION, signature_A1, signature_B1),
         ),
         {"from": B},
     )
 
+    withdraw_events = token_network.events.ChannelWithdraw.getLogs()
+    assert any(map(check_withdraw_2(channel_identifier, A, balance_A), withdraw_events))
+    assert any(map(check_withdraw_2(channel_identifier, B, balance_B), withdraw_events))
+
     ev_handler.add(
         txn_hash,
         ChannelEvent.SETTLED,
-        check_channel_settled(channel_identifier, balance_B, balance_A),
+        check_channel_settled(
+            channel_identifier,
+            B,
+            balance_B,
+            EMPTY_LOCKSROOT,
+            A,
+            balance_A,
+            EMPTY_LOCKSROOT,
+        ),
     )
     ev_handler.check()
