@@ -34,7 +34,7 @@ def test_update_call(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ Call updateNonClosingBalanceProof() with various wrong arguments """
+    """Call updateNonClosingBalanceProof() with various wrong arguments"""
     (A, B, C) = get_accounts(3)
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, 15, B)
@@ -62,7 +62,7 @@ def test_update_call(
     )
 
     # Failure with the zero address instead of A's address
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: participant address zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             EMPTY_ADDRESS,
@@ -72,7 +72,7 @@ def test_update_call(
         ).call({"from": C})
 
     # Failure with the zero address instead of B's address
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: partner address zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -82,7 +82,7 @@ def test_update_call(
         ).call({"from": C})
 
     # Failure with the zero signature
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed):  # TODO: sig check
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -92,7 +92,7 @@ def test_update_call(
         ).call({"from": C})
 
     # Failure with the empty balance hash
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: balance hash is zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -105,7 +105,7 @@ def test_update_call(
         ).call({"from": C})
 
     # Failure with nonce zero
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: nonce is zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -118,7 +118,7 @@ def test_update_call(
         ).call({"from": C})
 
     # Failure with the empty signature
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -152,7 +152,7 @@ def test_update_nonexistent_fail(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
 ) -> None:
-    """ updateNonClosingBalanceProof() on a not-yet openned channel should fail """
+    """updateNonClosingBalanceProof() on a not-yet openned channel should fail"""
     (A, B, C) = get_accounts(3)
     channel_identifier = 1
 
@@ -170,7 +170,7 @@ def test_update_nonexistent_fail(
         **balance_proof_A._asdict(),
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: channel id mismatch"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -188,7 +188,7 @@ def test_update_notclosed_fail(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
 ) -> None:
-    """ updateNonClosingBalanceProof() on an Opened channel should fail """
+    """updateNonClosingBalanceProof() on an Opened channel should fail"""
     (A, B, C) = get_accounts(3)
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, 25, B)
@@ -207,7 +207,7 @@ def test_update_notclosed_fail(
     assert settle_block_number > 0
     assert state == ChannelState.OPENED
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: channel not closed"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -264,7 +264,7 @@ def test_update_wrong_nonce_fail(
     )
 
     # updateNonClosingBalanceProof should fail for the same nonce as provided previously
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: nonce reused"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -275,7 +275,7 @@ def test_update_wrong_nonce_fail(
     balance_proof_A_same_nonce = create_balance_proof(
         channel_identifier, A, 12, 2, balance_proof_A.nonce, fake_bytes(32, "03")
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -294,7 +294,7 @@ def test_update_wrong_nonce_fail(
         msg_type=MessageTypeId.BALANCE_PROOF_UPDATE,
         **balance_proof_A_lower_nonce._asdict(),
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: nonce reused"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -323,7 +323,7 @@ def test_update_wrong_signatures(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ updateNonClosingBalanceProof() should fail with wrong signatures """
+    """updateNonClosingBalanceProof() should fail with wrong signatures"""
     (A, B, C) = get_accounts(3)
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, 25, B)
@@ -362,7 +362,7 @@ def test_update_wrong_signatures(
         {"from": A},
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -370,7 +370,7 @@ def test_update_wrong_signatures(
             *balance_proof_A_fake._asdict().values(),
             balance_proof_update_signature_B,
         ).call({"from": C})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -404,7 +404,7 @@ def test_update_channel_state(
     update_state_tests: Callable,
     txn_cost: Callable,
 ) -> None:
-    """ A successful updateNonClosingBalanceProof() call should not change token/ETH balances """
+    """A successful updateNonClosingBalanceProof() call should not change token/ETH balances"""
     (A, B, Delegate) = get_accounts(3)
     settle_timeout = 6
     deposit_A = 20
@@ -482,7 +482,7 @@ def test_update_channel_fail_no_offchain_transfers(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ Calls to updateNonClosingBalanceProof() fail with the zero nonce """
+    """Calls to updateNonClosingBalanceProof() fail with the zero nonce"""
     (A, B) = get_accounts(2)
 
     channel_identifier = create_channel(A, B)[0]
@@ -509,7 +509,7 @@ def test_update_channel_fail_no_offchain_transfers(
         {"from": A},
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: balance hash is zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -521,7 +521,7 @@ def test_update_channel_fail_no_offchain_transfers(
             EMPTY_SIGNATURE,
         ).call({"from": B})
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: nonce is zero"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -531,7 +531,7 @@ def test_update_channel_fail_no_offchain_transfers(
         ).call({"from": B})
 
 
-def test_update_not_allowed_after_settlement_period(
+def test_update_allowed_after_settlement_period(
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
@@ -540,7 +540,7 @@ def test_update_not_allowed_after_settlement_period(
     create_balance_proof_countersignature: Callable,
     web3: Web3,
 ) -> None:
-    """ updateNonClosingBalanceProof cannot be called after the settlement period. """
+    """updateNonClosingBalanceProof can be called after the settlement period."""
     (A, B) = get_accounts(2)
     settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
@@ -567,14 +567,13 @@ def test_update_not_allowed_after_settlement_period(
         {"from": A},
     )
     mine_blocks(web3, settle_timeout + 1)
-    with pytest.raises(TransactionFailed):
-        token_network.functions.updateNonClosingBalanceProof(
-            channel_identifier,
-            A,
-            B,
-            *balance_proof_A._asdict().values(),
-            balance_proof_update_signature_B,
-        ).call({"from": A})
+    token_network.functions.updateNonClosingBalanceProof(
+        channel_identifier,
+        A,
+        B,
+        *balance_proof_A._asdict().values(),
+        balance_proof_update_signature_B,
+    ).call({"from": A})
 
 
 def test_update_not_allowed_for_the_closing_address(
@@ -585,7 +584,7 @@ def test_update_not_allowed_for_the_closing_address(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
 ) -> None:
-    """ Closing address cannot call updateNonClosingBalanceProof. """
+    """Closing address cannot call updateNonClosingBalanceProof."""
     (A, B, M) = get_accounts(3)
     settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
@@ -625,7 +624,7 @@ def test_update_not_allowed_for_the_closing_address(
     )
 
     # Someone wants to update with later balance proof - not possible
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -633,7 +632,7 @@ def test_update_not_allowed_for_the_closing_address(
             *balance_proof_B_1._asdict().values(),
             balance_proof_update_signature_B,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -641,7 +640,7 @@ def test_update_not_allowed_for_the_closing_address(
             *balance_proof_B_1._asdict().values(),
             balance_proof_update_signature_B,
         ).call({"from": B})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -661,7 +660,7 @@ def test_update_invalid_balance_proof_arguments(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ updateNonClosingBalanceProof() should fail on balance proofs with various wrong params """
+    """updateNonClosingBalanceProof() should fail on balance proofs with various wrong params"""
     (A, B, C) = get_accounts(3)
     settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
@@ -729,7 +728,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.signature,
         other_token_network=token_network_test_utils,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -754,7 +753,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -779,7 +778,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -797,7 +796,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -819,7 +818,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.signature,
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -841,7 +840,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.signature,
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -863,7 +862,7 @@ def test_update_invalid_balance_proof_arguments(
         balance_proof_valid.signature[::-1],
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed):  # TODO: fixme
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -899,7 +898,7 @@ def test_update_signature_on_invalid_arguments(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ Call updateNonClosingBalanceProof with signature on invalid argument fails """
+    """Call updateNonClosingBalanceProof with signature on invalid argument fails"""
     (A, B, C) = get_accounts(3)
     settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
@@ -941,7 +940,7 @@ def test_update_signature_on_invalid_arguments(
         *balance_proof_valid._asdict().values(),
         other_token_network=token_network_test_utils,  # invalid token_network_address
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -959,7 +958,7 @@ def test_update_signature_on_invalid_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -977,7 +976,7 @@ def test_update_signature_on_invalid_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -995,7 +994,7 @@ def test_update_signature_on_invalid_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -1013,7 +1012,7 @@ def test_update_signature_on_invalid_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -1031,7 +1030,7 @@ def test_update_signature_on_invalid_arguments(
         b"\x00" * 32,  # invalid additional_hash
         balance_proof_valid.signature,
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -1049,7 +1048,7 @@ def test_update_signature_on_invalid_arguments(
         balance_proof_valid.additional_hash,
         balance_proof_valid.signature[::-1],
     )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier,
             A,
@@ -1087,7 +1086,7 @@ def test_update_replay_reopened_channel(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ updateNonClosingBalanceProof() should refuse a balance proof with a stale channel id """
+    """updateNonClosingBalanceProof() should refuse a balance proof with a stale channel id"""
     (A, B) = get_accounts(2)
     nonce_B = 5
     values_A = ChannelValues(deposit=10, transferred=0)
@@ -1153,7 +1152,7 @@ def test_update_replay_reopened_channel(
     )
 
     # Make sure we cannot update balance proofs after settleChannel is called
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: channel id mismatch"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier1,
             B,
@@ -1181,7 +1180,7 @@ def test_update_replay_reopened_channel(
     )
 
     assert channel_identifier1 != channel_identifier2
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/update: invalid non-closing sig"):
         token_network.functions.updateNonClosingBalanceProof(
             channel_identifier2,
             B,
@@ -1227,7 +1226,7 @@ def test_update_channel_event(
     create_balance_proof_countersignature: Callable,
     event_handler: Callable,
 ) -> None:
-    """ Successful updateNonClosingBalanceProof() emit BALANCE_PROOF_UPDATED events """
+    """Successful updateNonClosingBalanceProof() emit BALANCE_PROOF_UPDATED events"""
     ev_handler = event_handler(token_network)
     (A, B) = get_accounts(2)
     deposit_A = 10
