@@ -30,7 +30,7 @@ def test_withdraw_call(
     get_accounts: Callable,
     create_withdraw_signatures: Callable,
 ) -> None:
-    """ setTotalWithdraw() fails with various wrong arguments """
+    """setTotalWithdraw() fails with various wrong arguments"""
     (A, B) = get_accounts(2)
     withdraw_A = 3
     channel_identifier = create_channel_and_deposit(A, B, 10, 1)
@@ -84,7 +84,7 @@ def test_withdraw_call(
         )
 
     # Failure with the zero address insted of a participant's address
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier=channel_identifier,
             participant=EMPTY_ADDRESS,
@@ -95,7 +95,7 @@ def test_withdraw_call(
         ).call({"from": A})
 
     # Failure with zero as the total withdrawn amount
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: total withdraw is zero"):
         token_network.functions.setTotalWithdraw(
             channel_identifier=channel_identifier,
             participant=A,
@@ -106,7 +106,7 @@ def test_withdraw_call(
         ).call({"from": A})
 
     # Failure with the empty signature instead of A's
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed):  # TODO: why doesn't this throw an error message?
         token_network.functions.setTotalWithdraw(
             channel_identifier=channel_identifier,
             participant=A,
@@ -117,7 +117,7 @@ def test_withdraw_call(
         ).call({"from": A})
 
     # Failure with the empty signature instead of B's
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed):  # TODO: why doesn't this throw an error message?
         token_network.functions.setTotalWithdraw(
             channel_identifier=channel_identifier,
             participant=A,
@@ -147,11 +147,13 @@ def test_withdraw_call_near_expiration(
     create_withdraw_signatures: Callable,
     web3: Web3,
 ) -> None:
-    """ setTotalWithdraw() succeeds when expiration_block is one block in the future """
+    """setTotalWithdraw() succeeds when expiration_block is one block in the future"""
     (A, B) = get_accounts(2)
     withdraw_A = 3
     channel_identifier = create_channel_and_deposit(A, B, 10, 1)
-    expiration = web3.eth.block_number + 1
+    # The block must still be one block in the future when the transaction is
+    # processed, so we have to choose an expiration two block in the future
+    expiration = web3.eth.block_number + 2
 
     (signature_A_for_A, signature_B_for_A) = create_withdraw_signatures(
         [A, B], channel_identifier, A, withdraw_A, expiration
@@ -178,7 +180,7 @@ def test_withdraw_wrong_state(
     withdraw_channel: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ setTotalWithdraw() should fail on a closed or settled channel """
+    """setTotalWithdraw() should fail on a closed or settled channel"""
     (A, B) = get_accounts(2)
     withdraw_A = 1
 
@@ -208,7 +210,7 @@ def test_withdraw_wrong_state(
     (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
     assert state == ChannelState.CLOSED
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: channel not open"):
         withdraw_channel(channel_identifier, A, withdraw_A, UINT256_MAX, B)
 
     mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
@@ -229,7 +231,7 @@ def test_withdraw_wrong_state(
     (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
     assert state == ChannelState.REMOVED
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: channel not open"):
         withdraw_channel(channel_identifier, A, withdraw_A, UINT256_MAX, B)
 
 
@@ -242,16 +244,16 @@ def test_withdraw_bigger(
 
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: withdraw > deposit"):
         withdraw_channel(channel_identifier, A, deposit_A + deposit_B + 1, UINT256_MAX, B)
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: withdraw > deposit"):
         withdraw_channel(channel_identifier, B, deposit_A + deposit_B + 1, UINT256_MAX, A)
 
     withdraw_channel(channel_identifier, A, 3, UINT256_MAX, B)
     withdraw_channel(channel_identifier, B, 6, UINT256_MAX, A)
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: withdraw > deposit"):
         withdraw_channel(channel_identifier, A, deposit_A + deposit_B - 5, UINT256_MAX, B)
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: withdraw > deposit"):
         withdraw_channel(channel_identifier, B, deposit_A + deposit_B - 2, UINT256_MAX, A)
 
     withdraw_channel(channel_identifier, A, deposit_A + deposit_B - 7, UINT256_MAX, B)
@@ -274,7 +276,7 @@ def test_withdraw_wrong_signers(
         signature_B_for_A,
         signature_C_for_A,
     ) = create_withdraw_signatures([A, B, C], channel_identifier, A, withdraw_A, UINT256_MAX)
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -283,7 +285,7 @@ def test_withdraw_wrong_signers(
             signature_C_for_A,
             signature_B_for_A,
         ).call({"from": C})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -333,7 +335,7 @@ def test_withdraw_wrong_signature_content(
         [A, B], channel_identifier, A, withdraw_A - 1, UINT256_MAX
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -342,7 +344,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A_fake1,
             signature_B_for_A,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -351,7 +353,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A,
             signature_B_for_A_fake1,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -360,7 +362,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A_fake2,
             signature_B_for_A,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -369,7 +371,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A,
             signature_B_for_A_fake2,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -378,7 +380,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A_fake3,
             signature_B_for_A,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: channel id mismatch"):
         token_network.functions.setTotalWithdraw(
             channel_identifier,
             A,
@@ -387,7 +389,7 @@ def test_withdraw_wrong_signature_content(
             signature_A_for_A,
             signature_B_for_A_fake3,
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: expired"):
         call_and_transact(
             token_network.functions.setTotalWithdraw(
                 channel_identifier,
@@ -399,7 +401,7 @@ def test_withdraw_wrong_signature_content(
             ),
             {"from": A},
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: expired"):
         call_and_transact(
             token_network.functions.setTotalWithdraw(
                 channel_identifier,
@@ -579,7 +581,7 @@ def test_withdraw_replay_reopened_channel(
     channel_deposit(channel_identifier2, A, deposit_A, B)
 
     assert channel_identifier1 != channel_identifier2
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
             channel_identifier2,
             A,
