@@ -219,11 +219,6 @@ def test_deploy_script_raiden(
     with pytest.raises(RuntimeError):
         deployer.verify_deployment_data(deployment_data=deployed_contracts_info_fail)
 
-    deployed_contracts_info_fail = deepcopy(deployed_contracts_info)
-    deployed_contracts_info_fail["chain_id"] = 0
-    with pytest.raises(RuntimeError):
-        deployer.verify_deployment_data(deployment_data=deployed_contracts_info_fail)
-
     deployed_contracts_info_fail = deepcopy(deployed_contracts_info)
     deployed_contracts_info_fail["contracts"][CONTRACT_SECRET_REGISTRY]["address"] = EMPTY_ADDRESS
     with pytest.raises(RuntimeError):
@@ -287,13 +282,6 @@ def test_deploy_script_raiden(
     with pytest.raises(RuntimeError):
         deployer.verify_deployment_data(deployed_contracts_info_fail)
 
-    deployed_contracts_info_fail = deepcopy(deployed_contracts_info)
-    deployed_contracts_info_fail["contracts"][CONTRACT_TOKEN_NETWORK_REGISTRY][
-        "constructor_arguments"
-    ][1] = DEPLOYER_ADDRESS
-    with pytest.raises(RuntimeError):
-        deployer.verify_deployment_data(deployed_contracts_info_fail)
-
     deployed_contracts_info_fail = deepcopy(deployed_contracts_info)
     deployed_contracts_info_fail["contracts"][CONTRACT_TOKEN_NETWORK_REGISTRY][
         "constructor_arguments"
@@ -318,21 +306,6 @@ def test_deploy_script_raiden(
         )
 
 
-@pytest.mark.slow
-def test_deploy_script_raiden_0_37_0(
-    deployer_0_37_0: ContractDeployer,
-) -> None:
-    """Checks that `verify_deployment_data` works fine with older contracts."""
-    data = deployer_0_37_0.deploy_raiden_contracts(
-        max_num_of_token_networks=1,
-        reuse_secret_registry_from_deploy_file=None,
-        settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-        settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
-    )
-
-    deployer_0_37_0.verify_deployment_data(deployment_data=data)
-
-
 def test_deploy_raiden_reuse_secret_registry(
     deployer: ContractDeployer, deployed_raiden_info: DeployedContracts
 ) -> None:
@@ -796,25 +769,6 @@ def test_store_and_verify_services(
     )
 
 
-@pytest.mark.slow
-def test_alderaan_deployer(web3: Web3) -> None:
-    """A smoke test for deploying Alderaan version contracts"""
-    deployer = ContractDeployer(
-        web3=web3,
-        private_key=FAUCET_PRIVATE_KEY,
-        gas_limit=GAS_LIMIT,
-        gas_price=1,
-        wait=10,
-        contracts_version=ALDERAAN_VERSION,
-    )
-    deployer.deploy_raiden_contracts(
-        max_num_of_token_networks=2,
-        reuse_secret_registry_from_deploy_file=None,
-        settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-        settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
-    )
-
-
 def test_error_removed_option_raises() -> None:
     with pytest.raises(NoSuchOption):
         mock = MagicMock()
