@@ -2,11 +2,12 @@ import random
 
 from raiden_contracts.tests.utils.constants import UINT256_MAX
 from raiden_contracts.utils.signature import private_key_to_address
+from raiden_contracts.utils.type_aliases import PrivateKey
 
 
-def get_random_privkey() -> str:
+def get_random_privkey() -> PrivateKey:
     """Returns a random private key"""
-    return "0x%064x" % random.randint(1, UINT256_MAX)
+    return PrivateKey(random.randint(1, UINT256_MAX).to_bytes(32, byteorder="big"))
 
 
 def get_random_address() -> str:
