@@ -28,11 +28,12 @@ class TokenOperations:
         self.owner = private_key_to_address(self.private_key)
         self.wait = wait
         self.web3.middleware_onion.add(construct_sign_and_send_raw_middleware(self.private_key))
-        self.web3.eth.defaultAccount = self.owner  # type: ignore
+        self.web3.eth.default_account = self.owner
+
         self.web3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
     def is_valid_contract(self, token_address: ChecksumAddress) -> bool:
-        return self.web3.eth.getCode(token_address, "latest") != HexBytes("")
+        return self.web3.eth.get_code(token_address, "latest") != HexBytes("")
 
     def mint_tokens(self, token_address: ChecksumAddress, amount: int) -> TxReceipt:
         token_address = to_checksum_address(token_address)
@@ -50,7 +51,7 @@ class TokenOperations:
     def get_weth(self, token_address: ChecksumAddress, amount: int) -> TxReceipt:
         token_address = to_checksum_address(token_address)
         assert (
-            self.web3.eth.getBalance(self.owner) > amount
+            self.web3.eth.get_balance(self.owner) > amount
         ), "Not sufficient ether to make a deposit to WETH contract"
         assert self.is_valid_contract(
             token_address
@@ -198,7 +199,10 @@ def transfer(
     type=click.STRING,
 )
 @click.option(
-    "--token-address", required=True, help="Address of the token contract", type=click.STRING
+    "--token-address",
+    required=True,
+    help="Address of the token contract",
+    type=click.STRING,
 )
 @click.option("--address", help="Address of account to get Balance", type=click.STRING)
 def balance(rpc_url: URI, token_address: str, address: str) -> None:
